@@ -465,19 +465,19 @@ namespace JSC {
         // Laziness macros. Some are used by MacroAssemblerPPC.h, others here.
 
 // whether a (Trusted)Imm32 fits in an unsigned immediate value
-#define PPC_IMM_OK_U(x) (((x).m_value & 0xffff0000) == 0)
+#define PPC_IMM_OK_U(x) (MOZ_LIKELY(((x).m_value & 0xffff0000) == 0))
 
 // whether a (Trusted)Imm32 fits in a signed immediate value
-#define PPC_IMM_OK_S(x) (((x).m_value & 0xffff8000) == 0 || \
-    ((x).m_value & 0xffff8000) == 0xffff8000)
+#define PPC_IMM_OK_S(x) (MOZ_LIKELY(((x).m_value & 0xffff8000) == 0 || \
+    ((x).m_value & 0xffff8000) == 0xffff8000))
 
 // whether the offset part of an Address fits in a (signed) immediate value
-#define PPC_OFFS_OK(x) (((x).offset & 0xffff8000) == 0 || \
-    ((x).offset & 0xffff8000) == 0xffff8000)
+#define PPC_OFFS_OK(x) (MOZ_LIKELY(((x).offset & 0xffff8000) == 0 || \
+    ((x).offset & 0xffff8000) == 0xffff8000))
 
 // same test, but checking a bit ahead (for multiple loads)
-#define PPC_OFFS_INCR_OK(x, incr) ((((x).offset + incr) & 0xffff8000) == 0 || \
-    (((x).offset + incr) & 0xffff8000) == 0xffff8000)
+#define PPC_OFFS_INCR_OK(x, incr) (MOZ_LIKELY((((x).offset + incr) & 0xffff8000) == 0 || \
+    (((x).offset + incr) & 0xffff8000) == 0xffff8000))
 
 // convert SPRid to 10-bit split encoding (OPPCC appendix A, p.514)
 #define PPC_SPR(x) (((int)x>>5) | ((int)x & 31)<<5)
